/*
 * This file is part of gedit
 *
 * Copyright (C) 2001-2005 Paolo Maggi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GEDIT_PREFERENCES_DIALOG_H
#define GEDIT_PREFERENCES_DIALOG_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

void gedit_show_preferences_dialog (GtkWindow *parent);

G_END_DECLS

#endif /* GEDIT_PREFERENCES_DIALOG_H */
